#
# spec file for package datovka
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           datovka
Version:        4.18.0
Release:        bp154.1.57
Summary:        Library to access Czech eGov system "Datove schranky"
License:        GPL-3.0-or-later
Group:          Development/Libraries/Python
URL:            https://www.datovka.cz
Source0:        https://secure.nic.cz/files/datove_schranky/%{version}/%{name}-%{version}.tar.xz
Source1:        https://secure.nic.cz/files/datove_schranky/%{version}/%{name}-%{version}.tar.xz.sha256
# PATCH-FIX-UPSTREAM: remove some issues with current .pro file
Patch0:         datovka-fix-pro.patch
BuildRequires:  libqt5-linguist
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt5Core) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Gui) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Network) >= 5.2.0
BuildRequires:  pkgconfig(Qt5PrintSupport) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Sql) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Svg) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.2.0
BuildRequires:  pkgconfig(libdatovka) >= 0.1.2
Requires:       libqt5_sql_backend
Recommends:     %{name}-lang
# Included inside with different approach
Obsoletes:      python-dslib
%if 0%{?suse_version} < 1330
Requires(post): hicolor-icon-theme
Requires(post): update-desktop-files
Requires(postun): hicolor-icon-theme
Requires(postun): update-desktop-files
%endif

%description
A library for accessing ISDS (Informační system datovych schranek/
Data Box Information System) SOAP services as defined in Czech ISDS Act
(300/2008 Coll.) and implied documents.

%{?lang_package}

%prep
%autosetup -p1
sed -i \
    -e 's:lrelease:lrelease-qt5:g' \
    %{name}.pro

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
lrelease-qt5 datovka.pro
%qmake5 PREFIX=%{_prefix} DISABLE_VERSION_CHECK_BY_DEFAULT=1
%make_jobs

%install
%qmake5_install

# fix desktop file
sed -i \
    -e 's:Office;:Office;Network;Email;:g' \
    %{buildroot}%{_datadir}/applications/datovka.desktop
rm -rf %{buildroot}%{_datadir}/datovka/doc

%if 0%{?suse_version} < 1330
%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files
%license COPYING
%doc AUTHORS ChangeLog
%{_bindir}/datovka
%{_datadir}/applications/datovka.desktop
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/datovka.metainfo.xml
%dir %{_datadir}/datovka
%dir %{_datadir}/datovka/localisations/
%{_datadir}/datovka/localisations/datovka_cs.qm
%{_datadir}/datovka/localisations/datovka_en.qm
%{_datadir}/icons/hicolor/*

%changelog
* Mon Aug 30 2021 Jiri Slaby <jslaby@suse.cz>
- Update to 4.18.0
  * Changes to behaviour of the tag database object. The container emits
  signals when content changes. Application code catches these signals and
  updates the displayed data.
  * Enabling foreign key functionality when opening tag database.
  * Fixed problems with non-functional move assignments causing unnecessary
  memory copying in some occasions.
  * Using a single transaction to write data of a completely downloaded message
  into the database.
  * Fixed error when deleting entries from account database when removing
  an account.
  * Optimisations in database code.
  * Manually downloaded messages are checked for their identifiers and may be
  uploaded into records management service if a records management service is
  configured and if the message content has not been already downloaded. The
  dialogues notifying the user when the upload finishes are non-modal.
  * Able to query information about the sending of PDZs.
  * Password can be shown when creating a new account without entering the PIN.
  * When there are multiple choices how to pay for a commercial message when
  sending one then the user has the possibility to select the preferred way
  of payment if it is possible.
  * This build requires libdatovka-0.2.0 because of the modified structures for
  holding time values and because of the newly added functionality.
  * Fixed wrong mime type identification then sending ISDOC attachments.
* Fri Apr 23 2021 Jiri Slaby <jslaby@suse.cz>
- Update to 4.17.0
  * Lists of received or sent messages of a selected account can be synchronised
  separately.
  * For better understanding rephrased the notification in cases then no public
  nor a commercial data message can de sent to target data box.
  * Downloads of multiple messages are aggregated into one dialogue when these
  download have been triggered from the main window.
  * Changes of some content of the message databases (statuses, downloaded
  attachments, message deletion) are signalled via the database containers.
  * Added support for new data-box types PFO_ZNALEC and PFO_TLUMOCNIK.
  * Added delivery time and attachment downloaded fields to found message
  entries in search message dialogue. Found entries also can be filtered and
  sorted.
  * User can download data messages directly form the search message dialogue.
  * Selected messages in the search message dialogue can be exported or can be
  attached to an e-mail.
  * Unified std namespace resolution in C++ code.
  * This build requires libdatovka-0.1.2 because of the newly added data-box
  types.
  * The action 'Save all attachments' can be called in multiple selected
  messages at once. Attachment files are renamed when they have same or
  conflicting names within a single data message. Written files are
  not renamed if they conflict between messages or already existing files
  in the directory where the files are written to.
  * Increased the verbosity of logged entries when determining automatic upload
  targets for the records management service.
* Mon Mar  1 2021 Jiri Slaby <jslaby@suse.cz>
- Update to 4.16.0
  * Using libdatovka instead of libisds. Libdatovka is a fork of libisds and
  contains functionality which libisds still does not implement and which is
  needed by the application.
  * Added the possibility to manage data-box users which is similar to the
  functionality offered by the ISDS web interface.
  * Fixed sorting of Czech strings in table views when using Czech
  localisation.
  * Fixed application crashes on repeated full-text data-box searches.
  * Fixed navigation in table views in backup and restoration dialogue.
  * Added support for the EV6 event.
  * Improved tab order in send message window.
  * Added PostSignum Qualified CA 4 certificate.
  * Fixed a problem with shadow synchronisation after which a blank account name
  was sent in the records management report.
  * The notification dialogue informing the user about sending a postal data
  message can be disabled.
  * Added a short timeout before the immediate download of a freshly sent
  message.
  * Fixed error in ISDS type conversion code - invalid type string values have
  been fixed. Database-related incompatible code has been removed from code
  shared with mobile application.
  * Able to add contacts without name or address into recipient list when
  creating a message.
  * Fixed an error in remembering directory path when opening and viewing ZFO
  files from file system immediately after application start.
  * Replaced the 'Mark All as Read' action with 'Mark All Received as' sub-menu
  in the 'Data Box' menu of the top menu bar.
  * Renamed 'Authenticate Message' to 'Verify Message' in the 'Message' menu
  because it reflects better the performed operation.
  * Account and message selection status is kept in a separate structure. It is
  used to simplify the code for various actions in the main window.
  * Code responsible for enabling actions in the main window has been gathered
  into one method.
  * Improved GUI responsiveness when downloading message lists with complete
  new messages.
  * Suspending the worker pool does not affect tasks run via runSingle().
  * Added user_account_name field into upload_account_status structure. Sending
  account name in order to make account identification in the records
  management service a bit easier.
  * Fixed compilation with Qt-5.15.0. Replaced most of deprecated code with
  available modern alternatives.
  * Replaced datovka.appdata.xml with datovka.metainfo.xml.
- remove (fixed upstream)
  0001-Fixed-compilation-using-Qt-5.15.0.patch
  0001-avoid-using-deprecated-qs-rand.patch
  0001-gui-datovka-annotate-fall-through-cases.patch
* Fri Jun  5 2020 Jiri Slaby <jslaby@suse.com>
- add
  0001-avoid-using-deprecated-qs-rand.patch
  0001-gui-datovka-annotate-fall-through-cases.patch
  0001-Fixed-compilation-using-Qt-5.15.0.patch
* Mon Mar  9 2020 Jiri Slaby <jslaby@suse.com>
- Update to 4.15.0
  * Added support for shadow accounts (i.e. accounts without database).
  * Shadow accounts which don't cause message acceptance can be used to
  automatically download message lists.
  * Data-box contact lists can be sorted.
  * Fixed failing tests when no ISDS login credentials are supplied.
  * Using 'identification number' (IČO) instead of 'subject ID' (IČ).
  * Displaying leading zeros in identification numbers in account info page.
  * Windows application can be compiled and bundled with OpenSSL-1.1.1. Actual
  version of OpenSSL is determined by the version of the used Qt libraries.
  * Modified code about which the compiler has been giving deprecation warnings
  when compiling with Qt-5.14.
  * Implemented the upload_account_status records management service. The
  service sends brief reports about the account status containing summaries
  about the number of messages in different states in the data box. The
  summaries are generated when a records management service is used.
* Thu Nov 28 2019 Jiri Slaby <jslaby@suse.com>
- Update to 4.14.1
  * Able to log from command line into an account that user a MEP login
    procedure.
  * Able to verify qualified time stamps in a new format which is used in
    the testing environment since the end of August 2019 and is going to be used
    in the production environment.
  * Allowing *.pfx files for login certificates.
  * Sharing account credentials code with mobile application.
  * Fixed a problem with non-functional account deletion in Qt-5.10 and later.
  * Using username together with testing flag to internally identify accounts.
  * Added MEP (mobile key) login procedure, libisds-0.11 is required.
* Tue May 28 2019 Jiri Slaby <jslaby@suse.com>
- Update to 4.13.1
  * Fixes crashes during account synchronization.
* Wed Apr 17 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.13.0 bsc#1104620:
  * Account renaming now possible
  * Special format downloading now alloved to "spisova sluzba"
- Rebase patch datovka-fix-pro.patch
* Wed Jan 16 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.12.0 bsc#1104620:
  * Bigger attachments allowed (50MB)
  * HiDPI icons
  * Minor fixes
* Tue Oct 23 2018 Tomáš Chvátal <tchvatal@suse.com>
- Use %%license macros
* Thu Sep 13 2018 Tomáš Chvátal <tchvatal@suse.com>
- Version update to 4.11.0:
  * Few feature enhancements in mesage composing
* Fri Aug 17 2018 tchvatal@suse.com
- Update datovka-fix-pro.patch to contain fix for Leap 42.3 build
* Mon Aug 13 2018 tchvatal@suse.com
- Update to 4.10.3 bsc#1104620:
  * Added classes based on Qt types encapsulating various ISDS data types and
    structures. Sharing this code with mobile application.
  * Added per-account locking of communication contexts.
  * Modified database interface to accommodate new data types.
  * Explicitly specifying tab order for most windows and dialogues. It is also
    possible (on Windows and Linux) to cycle through actions in top tool bar.
  * Asking users for confirmation before deleting tags which are still assigned
    to some messages.
  * Added tooltip description of message state value in sent message list.
  * Added button to view account password when editing account credentials and
    PIN (master password) is enabled.
  * Added DigiCert Global Root G2 certificate.
  * Improved keyboard-based control of main and other dialogue windows. All
    important elements should be navigable only by keyboard (on Windows and
    Linux).
  * Fixed a problem with wrong conversion of obtained ISDS error statuses into
    readable text. This may have caused the programme to crash.
  * Fixed scaling of some icon-based control elements when using enlarged fonts
    on Windows.
  * Fixed message list sorting and filtering according to assigned tags.
  * Displaying busy cursor when switching between entries in account list.
  * New version notification can be blocked on Windows in runtime by setting
    specific registry values. It can also be blocked at compile time
    by using a configuration option when running qmake.
  * Extended resource information for the generated Windows executable.
  * Fixed project file include paths in order not to interfere with user-defined
    compiler flags.
  * Fixed problem with unpredictable construction order of global object
    instances.
  * Added missing conversion strings to some unknown message types.
  * Fixed issue causing the application to crash on macOS when switching
    between accounts and when having some text in the message filter field.
  * Fixed issue causing the application to crash on macOS when updating
    information about messages without a valid delivery time.
  * Re-enabled logging of transferred message on Windows data when setting
    debug verbosity to 3.
  * Code shared with mobile application has been placed into separate
    directory.
- Rebase patch datovka-fix-pro.patch
* Wed Jan 17 2018 tchvatal@suse.com
- Update to 4.10.1:
  * Few small fixes
  * MSI installer tweaks
- Refresh patch datovka-fix-pro.patch
* Fri Dec  1 2017 tchvatal@suse.com
- Version update to 4.10.0:
  * Can now encrypt passwords via master password
  * Better support for screen readers
* Sun Oct 22 2017 jslaby@suse.com
- Update Version update to 4.9.3
  * Fixed a problem when message list was not updated after account
    synchronisation when a message was selected.
  * Fixed a bug when database location may have been saved even though the
    databases reside in default location. This problem was visible especially
    on Windows.
- Update Version update to 4.9.2
  * Changed tag dialogue to contain two views when editing tag assignment.
  * Using the prefix 'ODZ_' for sent and 'DDZ_' for received data messages
    when uploading them into records management service.
  * Default documentation location can be changed when running qmake using the
    TEXT_FILES_INST_DIR variable.
  * Full-text data-box search does not block the search dialogue.
  * Full-text data-box search can be interrupted and restarted again without
    closing the dialogue.
  * Separated core and GUI code. Removed models from database interface.
  * Added new CLI option '--get-msg-ids'.
  * Command-line application without GUI can be built separately. This
    executable is going to be distributed in Windows packages together with
    the GUI application.
- Update Version update to 4.9.1
  * Added experimental support for new data-box and user types that are going
    to be introduced into the ISDS production environment and which are
    already present in the ISDS testing environment.
    Version 0.10.7 of libisds is required to build the application.
  * Updated building scripts for the Windows application to automatically pull
    Qt dependencies into the package.
  * Fixed issue when records management data have not been erased from message
    model after the service has been deactivated.
  * Fixed issues with records management logo not being displayed in message
    list immediately after the service has been set up.
  * Alphabetically sorting nodes of records management hierarchy.
  * Sub-nodes of matching element are also displayed when filtering hierarchy
    of records management service.
  * Removed inactive mojeid-datovka code from the sources.
* Wed Jul 19 2017 jengelh@inai.de
- Remove odd backslashes from description.
* Wed Jul 19 2017 jslaby@suse.com
- Version update to 4.9.0:
  * Added API and support for sending messages into records management
    services.
  * Removed explicit clear buttons from filter fields.
  * Fixed problems with remembering location of saved attachment files.
  * Directory structure can be created when exporting correspondence overview.
  * Line height of account list and message table has been adjusted to be the
    same.
  * Fixed confusion between the terms of delivery (dodani) and acceptance
    (doruceni) in Czech localisation.
  * Process of exporting multiple selected messages can be aborted by clicking
    Cancel button.
  * Tags can be stored into HTML correspondence overview.
  * HTML correspondence overview now contains both delivery and acceptance
    times.
  * Fixed problems with sending messages from accounts that cannot search for
    data boxes.
  * Fixed tag ordering. Tag sorting is now locale-aware.
- disable -Wdate-time -- unrecognized e.g. with gcc 4.8
* Tue May 23 2017 jslaby@suse.com
- Version update to 4.8.1:
  * Fixed problem with disappearing splitters on application start.
- add checksum to sources, so that OBS can check consistency
* Thu Mar 30 2017 tchvatal@suse.com
- Version update to 4.8.0:
  * Added full-text data box search which is now the default method to search
    for data boxes.
  * Fixed problems with placing the main application window when starting the
    application on a smaller screen than it has been closed before.
  * Refactoring of code related to message imports and exports.
  * Reduced the amount of code in main application window.
* Tue Mar 28 2017 tchvatal@suse.com
- Drop dejavu dependency as it is now using fontconfig and not hardcoded
  paths in the code
* Wed Mar  8 2017 tchvatal@suse.com
- Fix license to be GPL-3.0+ as per COPYING file
* Thu Feb 16 2017 mpluskal@suse.com
- Use qmake macros
* Wed Feb 15 2017 jslaby@suse.com
- Version update to 4.7.1:
  * User is notified about existent files when storing all attachments.
  * Added forward message action.
  * Fixed problem in which the main window was placed slightly off-screen when
  run for the first time.
  * When composing messages, attachment files can be rearranged using drag and
  drop actions.
  * Fixed bug. Message model is updated after tags have been edited.
  * Fixes errors in application localisation.
* Wed Oct 19 2016 tchvatal@suse.com
- Version update to 4.7.0:
  * openssl 1.1.0 support
  * Various small fixes
* Mon Oct 10 2016 jslaby@suse.com
- Version update to 4.6.1:
  * Message envelope can be exported to a PDF file along with other message
    attachments.
  * Fixed issue when the sending of a new message lasted too long. In such case
    the application could occasionally crash.
  * Patched bundled libisds to fix wrong sender identification. This fix
    affects only Windows and OS X users. Linux users should update to latest
    libisds version (0.10.4).
  * Fixed version string shown in notification dialogue.
* Sat May 14 2016 tchvatal@suse.com
- Version update to 4.6.0:
  * Added support for tags. These can be locally assigned to the messages.
  * Message information are shown in separate window when double-clicking the
    message in message list or when hitting the Return/Enter key.
  * When composing a message, the recipient can be added to the recipient list
    by double clicking it in the recently-used recipient list.
  * Information about personal delivery are shown in message description field.
  * Fixed problem where account entry has not been updated after message
    deletion.
  * Fixed encoding issue when exporting correspondence overview in HTML.
  * Fixed a bug causing the create message button not to activate when first
    account was created.
* Fri Apr  1 2016 mpluskal@suse.com
- Update to 4.5.3
  * Fixed problems with HOTP authorisation on Windows. There have
    been problems with the bundled libisds. MinGW does not handle
    POSIX extensions of printf formatting strings properly. Patch
    for libisds has been added.
  * Fixed a non-working PRAGMA statement when asking for a database
    integrity check.
  * The --version command-line argument now also prints the version
    of libraries which Datovka depends on.
  * Automatic background downloads didn't cause the deactivation of
    download buttons that could still be triggered. Triggering those
    buttons in this situation could cause the application to crash.
  * Adding new account caused the account tree to collapse. This has
    been fixed.
- Changes for 4.5.2
  * NLS of bundled libisds (OS X, Windows) has been disabled.
  * The logging of libisds actions has been restricted on Windows
    because there are discrepancies from standard-defined behaviour
    of some functions on Windows.
  * Improved behaviour when message download fails. The error
    dialogue is only shown when an explicit message download fails.
  * A message in the notification area appears when the download
    has been triggered by downloading message list. This should
    reduce the amount of error dialogues generated.
  * Improved behaviour when downloading messages on accounts with
    restricted privileges. Received messages are not automatically
    downloaded when the user has no privileges to do that.
- Changes for 4.5.1
  * Fixed bug in action logging causing the application to crash
    occasionally.
  * Fixed bug where message line was not deleted when deleting from
    ISDS failed.
  * New account model internals.
- Build with optflags
- Use macros for desktop file and icon handling
* Tue Feb 16 2016 tchvatal@suse.com
- Version update to 4.5.0:
  * various backend updates
  * various bugs fixed
  * qt 5.3 required now
- Rebase patch:
  * datovka-fix-pro.patch
* Tue Jan  5 2016 tchvatal@suse.com
- Version update to 4.4.3:
  * Various bugfixes. See ChangeLog file
  * Fixed broken expired password swap
* Mon Oct 12 2015 tchvatal@suse.com
- Version update to 4.4.0:
  * Various bugfixes all around. See ChangeLog file
* Sat Sep  5 2015 tchvatal@suse.com
- Version bump 4.3.1:
  * Few small bugfixes see ChangeLog for details
- Refresh patch datovka-fix-pro.patch
* Wed Jun  3 2015 tchvatal@suse.com
- Version bump to 4.3.0:
  * No obvious changelog apart from mentioning bugfixes
* Tue Mar 31 2015 tchvatal@suse.com
- Version bump to 4.2.0:
  * Various bugfixes
  * Resending messages/etc
- Obsoleted patch:
  * 0001-no-check-new-versions.patch
* Tue Feb 24 2015 tchvatal@suse.com
- Version bump to 4.1.2:
  * Various bugfixes
- Add patch to not ask about new version availabilty:
  * 0001-no-check-new-versions.patch
- Refreshed patch:
  * datovka-fix-pro.patch
* Mon Feb  2 2015 tchvatal@suse.com
- Version bump to 4.1:
  * Complete rewrite under qt5
  * Should provide same usability, reffer to homepage for more info
- Various cleanups
- Add patch to fix building with respecting cflags/etc:
  * datovka-fix-pro.patch
* Mon Sep 15 2014 tchvatal@suse.com
- Version bump to 3.1:
  * Detect better file suffixes
  * work with sqlalchemy 0.9
- Cleanup with spec-cleaner
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Jul 16 2013 tchvatal@suse.com
- Format spec file was run and it was not changelogged.
* Fri Jan 25 2013 tchvatal@suse.com
- Upstream moves the tarball all around, just not track it.
* Wed Jan 23 2013 tchvatal@suse.com
- Forgot to own datadir.
* Wed Jan 23 2013 tchvatal@suse.com
- Sort out desktop file for SLE.
* Wed Jan 23 2013 tchvatal@suse.com
- Fix various rpmlint warnings to make it happy.
* Wed Jan 23 2013 tchvatal@suse.com
- Add build_root and python stuff to theoretically build on sle.
* Wed Jan 23 2013 tchvatal@suse.com
- Add more runtime deps to be on safe side here.
* Mon Jan 21 2013 tchvatal@suse.com
- Fix download url as upstream decided to move it.
* Fri Jan 18 2013 tchvatal@suse.com
- Add py_requires macro.
* Mon Jan  7 2013 tchvatal@suse.com
- Version bump to 3.0.3.
* Thu Dec 20 2012 tchvatal@suse.com
- Version bump to 3.0.2. Raise dslib dep. Remove dejavu hack.
* Fri Nov 30 2012 tchvatal@suse.com
- Version bump to 2.1.1. Raise dslib dep.
* Thu Apr 26 2012 tchvatal@suse.com
- Bump to version 2.0.2. Depend on newer python-dslib.
* Wed Dec  7 2011 tchvatal@suse.com
- Remove _service, clean phase, add some docs
* Tue Dec  6 2011 tchvatal@suse.com
- Initial commit of datovka.
